@@ -280,8 +280,8 @@ parser.add_argument(
     "-E", "--list-env",
     action="store_true",
     help="list filter and global helper functions and stop (this will "
-          "include the standard Jinja2, as well as the netaddr module "
-          " and custom ones)")
+         "include the standard Jinja2, as well as the netaddr module "
+         "and custom ones)")
 
 parser.add_argument(
     "-I", "--dump-inventory",
@@ -289,6 +289,12 @@ parser.add_argument(
     help="dump complete read inventory in YAML to stdout and stop, "
          "without generating any configurations")
 
+parser.add_argument(
+    "-F", "--dump-filepaths",
+    action="store_true",
+    help="dump paths of files which are the source of each entry in "
+         "the inventory")
+
 parser.add_argument(
     "-U", "--dump-device",
     action="store_true",
@@ -339,6 +345,7 @@ no_output = args.no_output
 no_squash_blanklines = args.no_squash_blanklines
 list_env = args.list_env
 dump_inventory = args.dump_inventory
+dump_filepaths = args.dump_filepaths
 dump_device = args.dump_device
 quiet = args.quiet
 devicenames = args.devicename
@@ -399,9 +406,12 @@ inventory = NetInventory(inventory_dirname, debug=debug)
 
 
 if dump_inventory:
-    print(yaml.dump(inventory, default_flow_style=False))
+    print(yaml.dump(dict(inventory), default_flow_style=False))
     exit(0)
 
+if dump_filepaths:
+    print(yaml.dump(inventory.get_filepaths(), default_flow_style=False))
+    exit(0)
 
 if "devices" not in inventory:
     print("error: no devices found in inventory", file=sys.stderr)
